# setup.py

from setuptools import setup, find_packages
setup(
    name='tfw_tf',
    version='0.2',
    packages=find_packages(),
    description='Use for train and test model',
    author='Abinesh',
    author_email='abinesh530@gmail.com',
    python_requires='>=3.5',  # Specify the required Python version
)
